%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%



function [eff_n FieldBoundary evec]=AbsorbingLayer(RefTarget,v0Target,MaxLength,...
    dim,WPML,sPP,baratio,NumEigs,FunSign)


tStart=clock;

%close all;
sq=inline('x.*x','x');
lambda=1; % microns
k0=2*pi/lambda;
n1=1.45;
n2=n1*0.96;
E1=sq(n1); % cover epsilon, air
E2=sq(n2); % substrate epsilon, lithium niobate



wavenumber=2*pi/lambda;
a=sqrt(1/wavenumber^2/(n1^2-n2^2));

b=baratio*a;

xmin=-(MaxLength+WPML); % from xmin (in cover)
xmax=MaxLength+WPML; % to xmax (in substrate)
DeltaX=(xmax-xmin)/(dim);
f=1/(DeltaX*k0)^2;

prm0=ones(dim,1);
WPML=round(WPML/DeltaX)*DeltaX;
for ii=1:length(prm0)
    
    if(abs(xmin+(ii-1)*DeltaX)<a)
       prm0(ii)=E1;
    else
        if(abs(xmin+(ii-1)*DeltaX)<b)
            prm0(ii)=E2;
        else
            prm0(ii)=E1;
        end;
    end;
    if abs(xmin+(ii-1)*DeltaX)>xmax-WPML
        prm0(ii)=prm0(ii)*(1-i*((abs(xmin+(ii-1)*DeltaX)-(xmax-WPML))/WPML).^2*sPP);
    end;
end;


RefTarget=0;
L=sparse([2:dim 1:dim 1:dim-1]',[1:dim-1 1:dim 2:dim]', ...
    [f*ones(dim-1,1); (-2*f-sq(RefTarget))*ones(dim,1)+prm0; f*ones(dim-1,1)],dim,dim);


tol=1e-22;
opts.tol = tol;
opts.disp=1;
if length(v0Target)==dim
   opts.v0=v0Target;
end;
    runtime = etime(clock,tStart);
    fprintf('run time = %fs or %fm or %fh\n',runtime,runtime/60,runtime/3600);

FieldBoundary=zeros(NumEigs,1); 



[evecR, evalR]=eig(full(L));
eff_nR=sqrt(diag(evalR));
[C I]=sort(real(eff_nR));
eff_nR=eff_nR(I);
evecR=evecR(:,I);

[evecL, evalL]=eig(full(L.'));
eff_nL=sqrt(diag(evalL)+sq(RefTarget));
[C I]=sort(real(eff_nL));
evecL=evecL(:,I);



CoeffD=diag(evecL.'*evecR);

InputU=exp(-1*((xmin+((1:dim)'-1)*DeltaX).^2)/2/a/a);

CoeffC=evecL.'*InputU;

if FunSign==27
    
    %figure;plot(1:dim,[real(CoeffC) imag(CoeffC)]);
    %figure;plot(1:dim,[real(eff_nR) abs(imag(eff_nR))]);
  
  
    figure;[AX,H1,H2] = plotyy(1:dim,abs(imag(eff_nR)),...
        1:dim,real(eff_nR),'semilogy','plot');
    set(get(AX(1),'Ylabel'),'String','Im(n_{eff})'); 
    set(get(AX(2),'Ylabel'),'String','Re(n_{eff})');
    set(get(AX(1),'Xlabel'),'String','Mode index');
    set(H1,'LineWidth',1,'color','r');
    set(H2,'LineWidth',1,'Color','b');
    ylim(AX(1),[1e-5 10]);set(AX(1),'ytickMode','auto');
    ylim(AX(2),[0 2]);set(AX(2),'ytickMode','auto');
end;


eff_nR=real(eff_nR)-i*abs(imag(eff_nR));


if FunSign==28
    AbsorbingLayerPropagation(dim,a,b,MaxLength,WPML,DeltaX,CoeffC,CoeffD,evecR,eff_nR,k0);
end;

    
if FunSign==29
    Distance=linspace(1,50000,2000);
    ExpandInputUCenter=zeros(length(Distance),1);
    for Zii=1:length(Distance)
        ExpandInputUCenter(Zii)=evecR(end/2+1,:) ...
            *(CoeffC./CoeffD.*exp(-i*eff_nR*k0*Distance(Zii)));
    end;
    figure;semilogy(Distance, (abs(ExpandInputUCenter)).^2,'b','linewidth',2);
    for Zii=1:length(Distance)
         ExpandInputUCenter(Zii)=evecR(end/2+1,476) ...
             *(CoeffC(476)/CoeffD(476)*exp(-i*eff_nR(476)*k0*Distance(Zii)));
    end;        
    hold on;semilogy(Distance, (abs(ExpandInputUCenter)).^2,'r--','linewidth',2); 
    ylim([1e-30 1]);
    ylabel('I_{norm}');xlabel('z/\lambda');
end;








    
    
if FunSign==30
    AbsorbingLayerDecomp(InputU,dim,a,b,MaxLength,WPML,DeltaX,CoeffC,CoeffD,evecR,eff_nR,k0)
  
end;




    runtime = etime(clock,tStart);
    fprintf('run time = %fs or %fm or %fh\n',runtime,runtime/60,runtime/3600);
