%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%




function AbsorbingLayerPropagation(dim,a,b,MaxLength,WPML,DeltaX,CoeffC,CoeffD,evecR,eff_nR,k0)


xmin=-(MaxLength+WPML); % from xmin (in cover)
xmax=MaxLength+WPML; % to xmax (in substrate)
[C I] = max(abs(CoeffC));
ExpandInputUFund=evecR(:,I)*(CoeffC(I)./CoeffD(I));
    lambda=2*pi/k0;
    close all;
    Distance=[linspace(0,10,11) linspace(12,30,10) linspace(33,40,3)  ...
        linspace(44,60,5) linspace(65,100,8)...
        linspace(120,200,5) linspace(250,300,2) linspace(400,700,4) ...
        linspace(800,1400,4) linspace(1500,5000,8)  ...
        linspace(5500,10000,10) linspace(10500,20000,20)];
    for Zii=1:length(Distance)
        
        fprintf('Generating figure %d/%d\n',Zii,length(Distance));

        close all;
        figure(1);
        subplot(2,1,1);
        pos = get(gca, 'Position');
        set(gca,'Position', [pos(1) pos(2)-0.3 pos(3) pos(4)+0.3 ]);
   
        ExpandInputUMovie=evecR*(CoeffC./CoeffD.*exp(-i*eff_nR*k0*Distance(Zii)));
        plot(xmin+((1:dim)-1)*DeltaX,log10(abs(ExpandInputUMovie).^2/max(abs(ExpandInputUMovie).^2)), ...
            'b','linewidth',2);
        hold on;
        plot(xmin+((1:dim)-1)*DeltaX,log10(abs(ExpandInputUFund).^2/max(abs(ExpandInputUFund).^2)), ...
            'r--','linewidth',2);
        ylim([-3 0]);xlim([-20 20]);

        set(gca,'XTickLabel',[]);
        set(gca,'ytick',[-2 -1 0],'YTickLabel',[]);
        set(gca,'xtick',[-20 -10 0 10 20],'XTickLabel',[]);
        tls = [0.04 0.25];set(gca,'TickLength',tls);
        FONT_SIZE=30;


        htxt2 = text(0,0,'0');
        set(htxt2,'Position',[-21 -4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        htxt3 = text(0,0,int2str(max(Distance)));
        set(htxt3,'Position',[16 -4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        htxt14 = text(0,0,'{\it z} /{\it \lambda}');
        set(htxt14,'Position',[-3.2 -4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        hs = uicontrol('style','slider','position',[100 70 600 20],'Min',0,'Max',max(Distance),'SliderStep',[0.1  0.05]);
        set(hs,'Value',Distance(Zii))
  
        htxt4 = text(0,0,'{\it x} /{\it \lambda}');
        set(htxt4,'Position',[-3.6 -3.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.2);
        htxt5 = text(0,0,'Normalized power');
        set(htxt5,'Rotation',90,'Position',[-23 -2.5],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*0.9);
        htxt6 = text(0,0,'-20');
        set(htxt6,'Position',[-23 -3.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        htxt9 = text(0,0,'20');
        set(htxt9,'Position',[18 -3.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        htxt10 = text(0,0,'10');
        set(htxt10,'Position',[-24 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        htxt11 = text(0,0,'10');
        set(htxt11,'Position',[-24 -3],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
        htxt12 = text(0,0,'0');
        set(htxt12,'Position',[-21 0.1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.5);
        htxt13 = text(0,0,'-3');
        set(htxt13,'Position',[-22 -2.85],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.5);

        plot([a/lambda a/lambda],[-3 0],'k-.','LineWidth',2);
        plot([-a/lambda -a/lambda],[-3 0],'k-.','LineWidth',2);
        plot([b/lambda b/lambda],[-3 0],'k--','LineWidth',2);
        plot([-b/lambda -b/lambda],[-3 0],'k--','LineWidth',2);
        plot([MaxLength/lambda MaxLength/lambda],[-3 0],'k:','LineWidth',2);
        plot([-MaxLength/lambda -MaxLength/lambda],[-3 0],'k:','LineWidth',2);
  
        m=100+Zii;
        print('-dpsc2','-r100',strcat('movie/Fig28_',int2str(m),'.ps'));
        % mogrify -format gif *ps

    end;