%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function [eff_n FieldBoundary evec]=AbsorbingLayerSolver(RefTarget,v0Target,MaxLength,...
    dim,WPML,sPP,baratio,NumEigs,PlotSign)



tStart=clock;


sq=inline('x.*x','x');
lambda=1e-6; % microns
wavenumber=2*pi/lambda;
n1=1.45;
n2=n1*0.96;
E1=sq(n1); % cover epsilon, air
E2=sq(n2); % substrate , lithium niobate


a=sqrt(1/wavenumber^2/(n1^2-n2^2));
b=baratio*a;
t=0.4;
EW=2; % delta epsilon width, microns
xmin=-(MaxLength+WPML); % from xmin (in cover)
xmax=MaxLength+WPML; % to xmax (in substrate)
 DeltaX=(xmax-xmin)/(dim-1);
f=1/(DeltaX*wavenumber)^2;

EpsilonV=ones(dim,1);
WPML=round(WPML/DeltaX)*DeltaX;
for ii=1:length(EpsilonV)
    
    if(abs(xmin+(ii-1)*DeltaX)<a)
       EpsilonV(ii)=E1;
    else
        if(abs(xmin+(ii-1)*DeltaX)<b)
            EpsilonV(ii)=E2;
        else
            EpsilonV(ii)=E1;
        end;
    end;
    if abs(xmin+(ii-1)*DeltaX)>xmax-WPML
         EpsilonV(ii)=EpsilonV(ii)*(1+i*((abs(xmin+(ii-1)*DeltaX)-(xmax-WPML))/WPML).^2*sPP);
    end;
end;


L=sparse([2:dim 1:dim 1:dim-1]',[1:dim-1 1:dim 2:dim]', ...
    [f*ones(dim-1,1); (-2*f-sq(RefTarget))*ones(dim,1)+EpsilonV; f*ones(dim-1,1)],dim,dim);


opts.tol = 1e-22;
opts.disp=1;
if length(v0Target)==dim
   opts.v0=v0Target;
end;
runtime = etime(clock,tStart);

FieldBoundary=zeros(NumEigs,1); FieldMaxium=zeros(NumEigs,1);
[evec, eval]=eigs(L,NumEigs,'sm',opts);
eff_n=sqrt(diag(eval)+sq(RefTarget));

for ii=1:NumEigs
    FieldBoundary(ii)=(abs(evec(1,ii))+abs(evec(end,ii)))./abs(evec(end/2,ii))/2;
    FieldMaxium(ii)=max(abs(evec(:,ii)/evec(end/2,ii)));
    fprintf('Boundary(%d)=%e,Maxium(%d)=%e,eff_n(%d)=%10f+i*(%e)\n' ...
            ,ii,FieldBoundary(ii),ii,FieldMaxium(ii),ii,real(eff_n(ii)),imag(eff_n(ii)));
end;
    runtime = etime(clock,tStart);
 %   fprintf('run time = %fs or %fm or %fh\n',runtime,runtime/60,runtime/3600);

if PlotSign==1
    guided=log10(abs(evec./(ones(dim,1)*evec(end/2,:))));
    
    figure;subplot(2,1,1);plot(xmin+((1:dim)-1)*DeltaX,[real((EpsilonV)) imag((EpsilonV))]);
    subplot(2,1,2);plot(xmin+((1:dim)-1)*DeltaX,guided);
    guided=evec./(ones(dim,1)*evec(end/2,:));%/max(evec);
    figure;plot(xmin+((1:dim)-1)*DeltaX,real(guided),'r');
        hold on;plot(xmin+((1:dim)-1)*DeltaX,imag(guided),'b');

end;