%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%


function Bandgap(NormXLength,RatioPulseWidth,N,ShinkXLengthFactor,TypeFunction)


TestSign=0;
sq=inline('x.*x','x');


n1=2.89;
n2=3.38;
na=1;

lambda = 1.15e-6;
pitch=2*0.1e-6;
t=1.2e-6; % t=2d in the paper




wavenumber=2*pi/lambda;
a=pitch/2;
Endwithn1sign=0;
save data/Endwithn1sign.dat Endwithn1sign  -ascii -tabs;

%save data/lambda.dat lambda -ascii -tabs;
%save data/pitch.dat pitch -ascii -tabs;
%save data/a.dat a -ascii -tabs;
%save data/b.dat b -ascii -tabs;
%save data/n1.dat n1 -ascii -tabs;
%save data/n2.dat n2 -ascii -tabs;
%save data/na.dat na -ascii -tabs;
%save data/t.dat t -ascii -tabs;
%save data/numlayer.dat numlayer -ascii -tabs;
%save data/debugsign.dat debugsign  -ascii -tabs;
%save data/displaysign.dat displaysign  -ascii -tabs;


SpeedLight=2.99e8;
XLength = NormXLength*pitch;
deltaX=a/10;

XNum = round(XLength/ShinkXLengthFactor/deltaX);
x=(-XNum:XNum)*deltaX;

omega=2*pi/2/XLength;

plotsign=0;


PulseWidth=t/2; fx=exp(-x.*x/2/PulseWidth/PulseWidth);


if(exp(-(XLength/ShinkXLengthFactor).^2/2/PulseWidth/PulseWidth)>1e-10)
        fprintf('ShinkXLengthFactor is too big =%f\n,please reset ShinkXLengthFactor\n',exp(-(XLength/ShinkXLengthFactor).^2/2/PulseWidth/PulseWidth));
        stop
else
         fprintf('ShinkXLengthFactor ==%e\n',exp(-(XLength/ShinkXLengthFactor).^2/2/PulseWidth/PulseWidth));
 
end;

[neffR neffI] =BandgapLeaky(na,n1,n2,t,pitch,N,wavenumber);
fprintf('result from SlabLeaky Neff = %f+ %6e*i \n',neffR,neffI);



%Endk2x=sqrt(sq(n2*wavenumber)-sq(-0.7*i*wavenumber));
Endk2x=3.5*wavenumber;

if TypeFunction==20
    Endk2x=(n2+3)*wavenumber;
end;
Startk2x =0.001*wavenumber;;



numSeries = round((Endk2x-Startk2x)/(2*pi/2/XLength))+10;
fprintf('numSeries is reset to %d \n',numSeries);
[k2x numSeries] = BandgapGetk2xSet(Startk2x,Endk2x,na,n1,n2,t,pitch,N,...
    XLength,deltaX,wavenumber,numSeries,plotsign);

omegawidth = (k2x(3:end) - k2x(1:end-2))/2;
omegawidth = [omegawidth(1); omegawidth; omegawidth(end)];

fprintf('finish BandgapGetk2xSet with numSeries = %d\n',numSeries);


if(Endwithn1sign==1)
    beta=sqrt(sq(wavenumber*n1)-sq(k2x));
else
    beta=sqrt(sq(wavenumber*n2)-sq(k2x));
end;




fprintf('Finish BandgapGetk2xSet\n');
alpha=zeros(numSeries,1); 
A=zeros(numSeries,1); 



for	nii=1:numSeries
	[A(nii) alpha(nii)]=BandgapGetCouplingCoeff(PulseWidth,na,n1,n2,t,pitch,N,...
            XLength,deltaX,wavenumber,beta(nii),ShinkXLengthFactor,plotsign);
end;


fprintf('Finish BandgapGetCouplingCoeff\n');


if(plotsign==1)
    
    [M I] = max(A);
    if(I<length(A))
        betaeff = linspace(beta(I-1),beta(I+1),10);
        fprintf('Finish BandgapeffGetCouplingCoeff\n');
        [Meff Ieff] = max(Aeff);
        betamax = betaeff(Ieff);
    else
        betamax = beta(I);
    end;
    eigshape = Bandgapplotback(na,n1,n2,t,pitch,N,XLength,deltaX,wavenumber,...
    betamax,ShinkXLengthFactor,plotsign);
    inputshape = exp(-x.*x/PulseWidth/PulseWidth/2);
    inputshape2 = sech(x/PulseWidth);
    
    figure;plot(x/lambda,eigshape/max(abs(eigshape)),'r');hold on; 
    plot(x/lambda,inputshape,'b');plot(x/lambda,inputshape2,'g');
    plot([-t/pitch/2; -t/pitch/2],[1.5;-1.5],'r-.');
    plot([t/pitch/2; t/pitch/2],[1.5;-1.5],'r-.');
    plot([-(N*pitch + t/2)/pitch; -(N*pitch + t/2)/pitch],[1.5;-1.5],'r--');
    plot([(N*pitch + t/2)/pitch; (N*pitch + t/2)/pitch],[1.5;-1.5],'r--');
    axis([-50 50 -1.2 1.2]);
    Eff = betamax/wavenumber;
    fprintf('Approxiate effecitve index at peak is %f\n',Eff);
end;



if TestSign==1
    fprintf('Test decomposition\n');
    fxappr = zeros(length(x),1);
    for	nii=1:numSeries
        fxappr=fxappr+A(nii)*omegawidth(nii)*Bandgapplotback(na,n1,n2,t,pitch,N,...
            XLength,deltaX,wavenumber,beta(nii),ShinkXLengthFactor,plotsign);
    end;
	figure;	plot(x/lambda,[sq(abs(fx)).' sq(abs(fxappr))]);	
    axis([min(x)/a,max(x)/a,-0.2,1]); 
    Relerror = log10(sum(abs(fxappr-fx.'))/length(fx.'));
    Maxerror = max(abs(fxappr-fx.'));

    fprintf('fxappr peak=%f Relerror = %f, Maxerror = %f, dk*z = %f\n',...
        fxappr((end+1)/2),Relerror,Maxerror,omega/SpeedLight*5*lambda);
end;


if TypeFunction==19
    figure;title('Fig. 19(a)');
    [AX,H1,H2] = plotyy(k2x/wavenumber,abs(A).^2/max(abs(A).^2),...
        k2x/wavenumber,real(beta)/wavenumber);
    set(get(AX(1),'Ylabel'),'String','P(K_x)'); 
    set(get(AX(2),'Ylabel'),'String','Re(n_{eff})');
    set(get(AX(1),'Xlabel'),'String','K_x/k_0');
    set(H1,'LineWidth',2);
    set(H2,'LineStyle','--','LineWidth',2,'Color','r');
    ylim(AX(2),[0 4]);set(AX(2),'ytickMode','auto');
    xlim(AX(1),[0 3.5]);set(AX(1),'xtickMode','auto');
    xlim(AX(2),[0 3.5]);set(AX(2),'xtickMode','auto');    
    
    figure;title('Fig. 19(b)');
    [AX,H1,H2] = plotyy(k2x/wavenumber,abs(A).^2/max(abs(A).^2),...
        k2x/wavenumber,real(beta)/wavenumber,'semilogy','plot');
    set(get(AX(1),'Ylabel'),'String','P(K_x)'); 
    set(get(AX(2),'Ylabel'),'String','Re(n_{eff})');
    set(get(AX(1),'Xlabel'),'String','K_x/k_0');
    set(H1,'LineWidth',2);
    set(H2,'LineStyle','--','LineWidth',2,'Color','r');
    ylim(AX(1),[1e-6 1]);set(AX(2),'xtickMode','auto');
    ylim(AX(2),[0 4]);set(AX(2),'ytickMode','auto');
    xlim(AX(1),[0 3.5]);set(AX(1),'xtickMode','auto');
    xlim(AX(2),[0 3.5]);set(AX(2),'xtickMode','auto');
end;    
    
    

if(TypeFunction==20)
    BandgapPropagation(A,omegawidth,beta,na,n1,n2,t,pitch,N,numSeries,...
        wavenumber,plotsign)
end;

if(TypeFunction==21)
    BandgapModeEvolution(A,beta,na,n1,n2,t,pitch,N,numSeries,...
        wavenumber,XLength,deltaX,ShinkXLengthFactor,plotsign);
end;

if(TypeFunction==22)
    BandgapVaryN(PulseWidth,A,alpha,beta,Startk2x,Endk2x,na,n1,n2,t,pitch,N,numSeries,wavenumber,...
        XLength,deltaX,ShinkXLengthFactor,plotsign);
end;





