%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function Matrix0 = BandgapModeEvolution(A,beta,na,n1,n2,t,pitch,N,numSeries,...
        wavenumber,XLength,deltaX,ShinkXLengthFactor,plotsign)
sq=inline('x.*x','x');
FONT_SIZE=30;
XLength=XLength/ShinkXLengthFactor*50;

ShinkXLengthFactor=1;
deltaX=deltaX*10;
a=pitch/2;
b=pitch/2;
XLength_M = 2500*a;

XNum_M=100;
deltaX_M=XLength_M/XNum_M;

ZNum=100;

Matrix0=zeros(ZNum,1);
lambda=2*pi/wavenumber;
ZLength=50*lambda;
DeltaZ = ZLength/ZNum;

load data/Endwithn1sign.dat;
if(Endwithn1sign==1)
    gamma= sqrt(sq(n1*wavenumber)-beta.*beta);
else
    gamma= sqrt(sq(n2*wavenumber)-beta.*beta);
end;
omegawidth = gamma(2:end) - gamma(1:end-1);
omegawidth = [omegawidth; omegawidth(end)];
lambda = 2*pi/wavenumber;

x_M=linspace(-XNum_M,XNum_M,2*XNum_M+1).'*deltaX_M;
Vector_Z = linspace(0,ZNum,ZNum+1)*DeltaZ;

[neffR neffI] =BandgapLeaky(na,n1,n2,t,pitch,N,wavenumber);
fprintf('result from SlabLeaky Neff = %f+ %f*i \n',neffR,neffI);
neff=neffR+i*neffI;

[xLeaky EyLeaky] = BandgapLeakyMode(neff,na,n1,n2,t,pitch,N,wavenumber,XLength);


MatrixPlotback = zeros(numSeries,2*XNum_M+1);

tempx=(round(-XLength/ShinkXLengthFactor/deltaX):round(XLength/ShinkXLengthFactor/deltaX))*deltaX;
for nii=1:numSeries
   tempnii = Bandgapplotback(na,n1,n2,t,pitch,N,...
               XLength,deltaX,wavenumber,beta(nii),ShinkXLengthFactor,plotsign);
   tempnii=interp1(tempx,tempnii,x_M,'linear');
   MatrixPlotback(nii,:) = A(nii)*tempnii*omegawidth(nii);
end;



for zii=1:ZNum+1

    fprintf('Generating figure %d/%d\n',zii,ZNum+1);
    close all;
    figure; hold off;
    MatrixPos0=MatrixPlotback.'*exp(i*beta*Vector_Z(zii));
    MatrixPos0 = MatrixPos0/max(MatrixPos0);
    subplot(2,1,1);
    pos = get(gca, 'Position');
    set(gca,'Position', [pos(1) pos(2)-0.3 pos(3) pos(4)+0.3 ]);
    plot(x_M/lambda,log10(sq(abs(MatrixPos0))),'LineWidth',2);hold on;
    set(gca,'XTickLabel',[]);
    set(gca,'ytick',[-4 -3 -2 -1 0],'YTickLabel',[]);
    plot(xLeaky/lambda,log10(sq(abs(EyLeaky))),'r--','linewidth',2);
    XLimit=200;
    YLimit=4;
    axis([-XLimit XLimit -YLimit 0]);
    tls = [0.04 0.25];set(gca,'TickLength',tls);

  
  
    htxt = text(0,0,'0');
    set(htxt,'Position',[-205 -5.4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    htxt = text(0,0,'50');
    set(htxt,'Position',[185 -5.4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    htxt = text(0,0,'{\it z} /{\it \lambda}');
    set(htxt,'Position',[-30 -5.4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    hs = uicontrol('style','slider','position',[100 65 600 20],'Min',1,'Max',ZNum+1,'SliderStep',[0.1  0.05]);
    set(hs,'Value',zii)
    set(gca,'XTickLabel',[]);
    set(gca,'YTickLabel',[]);
	htxt = text(0,0,'{\it x} /{\it \lambda}');
	set(htxt,'Position',[-XLimit/2+65 -YLimit-0.25],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.2);
	htxt = text(0,0,'Normalized power');
	set(htxt,'Rotation',90,'Position',[-XLimit-25 -YLimit+0.6],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*0.9);
	htxt = text(0,0,'-100');
	set(htxt,'Position',[-XLimit-27 -YLimit-0.25],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'100');
	set(htxt,'Position',[XLimit-20 -YLimit-0.25],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'10');
	set(htxt,'Position',[-XLimit-40 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'10');
	set(htxt,'Position',[-XLimit-40 -YLimit+0.02],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'0');
	set(htxt,'Position',[-XLimit-13 0.17],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.5);
	htxt = text(0,0,'-4');
	set(htxt,'Position',[-XLimit-23 -YLimit+0.25],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.5);
    m=100+zii;
    print ('-dpsc2',strcat('movie/Fig21_',int2str(m),'.ps'));
end;
