%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function ThreeLayer(numSeries,NormXLength,ShinkXLengthFactor,FigNumber)


TestSign=0;

sq=inline('x*x','x');
n1=1.45;
n2= 0.96*n1;
lambda=1e-6;
wavenumber=2*pi/lambda;
a= sqrt(1/wavenumber^2/(n1^2-n2^2));




%a=lambda*2
c=2.99e8;
XLength = NormXLength*a;
deltaX = a/10;
%NumPoints = 10000;
%deltaX=XLength/NumPoints;
plotsign=0;

x = deltaX*(-round(XLength/ShinkXLengthFactor/deltaX):round(XLength/ShinkXLengthFactor/deltaX));

omega=2*pi/2/XLength;

ne = ThreeLayerAnalytical(n1,n2,a,wavenumber,plotsign);

beta0=ne*wavenumber;
width=a;


[A0 temp1 temp2]=ThreeLayerGetCouplingCoeff(width,n1,n2,a,XLength,...
        deltaX,wavenumber,ne*wavenumber,ShinkXLengthFactor);
%fprintf('Coupling Coeff for Fundmental mode is %f\n',A0);
fx=exp(-x.*x/2/width/width);


if(exp(-(XLength/ShinkXLengthFactor).^2/2/width/width)>1e-10)
        fprintf('ShinkXLengthFactor is too big =%e\n,please reset ShinkXLengthFactor\n',exp(-(XLength/ShinkXLengthFactor).^2/2/width/width));
        stop

%         fprintf('ShinkXLengthFactor=%d field at B==%e\n',ShinkXLengthFactor,exp(-(XLength/ShinkXLengthFactor).^2/2/width/width));
end;




[rho numSeries]= ThreeLayerGetRhoSet(n1,n2,a,XLength,wavenumber,numSeries,plotsign); 

%fprintf('numSeries is set to %d\n',numSeries);
beta= sqrt(sq(n2*wavenumber)-rho.*rho);

for	nii=1:numSeries
	[A(nii) Ce(nii) De(nii)]=ThreeLayerGetCouplingCoeff(width,n1,n2,a,XLength,...
            deltaX,wavenumber,beta(nii),ShinkXLengthFactor);
end;



omegawidth = rho(2:end) - rho(1:end-1);
omegawidth = [omegawidth omegawidth(end)];

if TestSign==1
    fprintf('Test decomposition\n');
    fxappr=A0*ThreeLayerPlotback(n1,n2,a,XLength,deltaX,wavenumber,beta0,ShinkXLengthFactor,plotsign);
    for	nii=1:numSeries
        beta(nii)=sqrt(sq(n2*wavenumber)-sq(nii*omega));
        fxappr=fxappr+A(nii)*omegawidth(nii)*ThreeLayerPlotback(n1,n2,a,XLength,deltaX,wavenumber,beta(nii),ShinkXLengthFactor,plotsign);
    end;
    figure;
    plot(x/a,[fxappr; fx]);
    error = log10(sum(abs(fxappr-fx))/length(fx));
    fprintf('error = %f, dk*z = %f\n',error,omega/c*5*lambda);
end;


if FigNumber==6
    figure;[AX,H1,H2] = plotyy(rho/wavenumber,abs(A).^2/max(abs(A).^2),...
            rho/wavenumber,real(beta)/wavenumber);
    set(get(AX(1),'Ylabel'),'String','P(k_x)'); 
    set(get(AX(2),'Ylabel'),'String','Re(n_{eff})');
    set(get(AX(2),'Xlabel'),'String','k_x/k_0');
    set(H1,'LineWidth',2);
    set(H2,'LineStyle','--','LineWidth',2,'Color','r');
    ylim(AX(2),[0 2]);
    xlim(AX(1),[0 2]);
    xlim(AX(2),[0 2]);

end;


if FigNumber==7
    ThreeLayerPropagation(A,A0,beta,beta0,n1,n2,a,numSeries,...
        wavenumber,XLength,deltaX,ShinkXLengthFactor);
end;

if FigNumber==8
    sq=inline('x.*x','x');
    format long;
    lambda = 2*pi/wavenumber;
    rho= sqrt(sq(n2*wavenumber)-beta.*beta);
    omegawidth = rho(2:end) - rho(1:end-1);
    omegawidth = [omegawidth omegawidth(end)];

    ZNum=40;
    ZLength=30*lambda;
    DeltaZ = ZLength/ZNum;
    Matrix0=zeros(ZNum+1,1);
	Vector_Z = linspace(0,ZNum,ZNum+1)*DeltaZ;
    for nii=1:numSeries
        tempii=A(nii)*Ce(nii)*omegawidth(nii);
        for ii=1:ZNum+1
            Matrix0(ii)=Matrix0(ii)+tempii*exp(i*beta(nii)*Vector_Z(ii));
        end;
    end;

    Matrix0=Matrix0+A0*exp(i*beta0*Vector_Z');
    z=Vector_Z;
    figure;  semilogy(z/lambda,sq(abs(Matrix0)),'bo');hold on;

    ZNum=400;
    DeltaZ = max(z)/ZNum;
    z=linspace(1,ZNum,ZNum)*DeltaZ;
    rho= sqrt(sq(n2*wavenumber)-beta.*beta);
    %A0=A(1)-rho(1)*(A(2)-A(1))/(rho(2)-rho(1));
    AP = (A(2)-A(1))/(rho(2)-rho(1));
    %Ce0=CeSend(1)-rho(1)*(CeSend(2)-CeSend(1))/(rho(2)-rho(1));
    CeP= (Ce(2)-Ce(1))/(rho(2)-rho(1));
    %figure(19); plot(rho,A.*CeSend);hold on; plot(rho,A0*Ce0+AP*CeP.*rho.*rho);
    phy0=n2*2*pi/lambda*z;
    phyPP=-z*(lambda/2/pi/n2);
    ExzFund=A0*exp(i*beta0*z);
    Exz2st = AP*CeP.*exp(i*phy0).*(sqrt(-1./phyPP)).^3.*((1-i)/sqrt(2)).^3*sqrt(2*pi)/2;
    semilogy(z/lambda,abs(ExzFund+Exz2st).*abs(ExzFund+Exz2st),'r--','LineWidth',2);
    ylim([0.1 10]);
    ylabel('I_{norm}');
    xlabel('z/\lambda');
end;

