%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function [Coeff Ce De]= ThreeLayerGetCouplingCoeff(width,n1,n2,a,TotalLength,deltaL,k0,beta,ShinkXLengthFactor)
Ce=0;
De=0;
sq=inline('xinput*xinput','xinput');
if( sq(beta/k0)>sq(n2) && sq(beta/k0)<sq(n1))


	kapa=sqrt(sq(k0*n1)-sq(beta));
	sigma=sqrt(sq(beta)-sq(k0*n2));
	x1=-a:deltaL:a;
	Ey1=cos(kapa*x1);
	x2=a+deltaL:deltaL:TotalLength/ShinkXLengthFactor;
	Ey2=cos(kapa*a)*exp(-sigma*(x2-a));
	x = [-1*fliplr(x2) x1 x2];
	Ey = [fliplr(Ey2) Ey1 Ey2];
	fx = exp(-1*x.*x/2/width/width);
	CoeffNeu = sum(fx.*conj(Ey))*deltaL;
	CoeffDen = sum(Ey.*conj(Ey))*deltaL;
	Coeff = CoeffNeu/CoeffDen;

else
	rho=sqrt(sq(k0*n2)-sq(beta));
	sigma=sqrt(sq(k0*n1)-sq(beta));
	Ce=1;
	De=Ce/2*exp(i*rho*a)*(cos(sigma*a)-i*sigma/rho*sin(sigma*a));
	Fe=conj(De);
	x1=-a:deltaL:a;
	Ey1=Ce*cos(sigma*x1);
	x2=a+deltaL:deltaL:TotalLength/ShinkXLengthFactor;
	Ey2=De*exp(-i*rho*x2)+Fe*exp(i*rho*x2);
	x = [-1*fliplr(x2) x1 x2];
	Ey = [fliplr(Ey2) Ey1 Ey2];
	numa= round((TotalLength/ShinkXLengthFactor-a)/deltaL);
	fmax = (max(abs(Ey(end-numa+1:end))));
    Ey = Ey/fmax;
    Ce = Ce/fmax;
    De = De/fmax;
	fx = exp(-1*x.*x/2/width/width);
	Coeff = sum(fx.*Ey)/pi*deltaL;
end;


