%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function Uniformmedium(numSeries,NormXLength,FigNumber)

%Uniformmedium(1000,3); %  generate Coeff ;
%Uniformmedium(1000,4); %  generate Propagation ;
%Uniformmedium(1000,5); %  generate asymptotic result


close all;


sq=inline('x.*x','x');
lambda=1e-6;
wavenumber=2*pi/lambda;
n=1.45;
XLength = NormXLength*lambda;
omega=2*pi/2/XLength;
XNum = 5000;
dx=2*XLength/XNum;
x=(-XNum:XNum)*dx;
fx=exp(-x.^2/lambda^2/2);

A=zeros(1,numSeries);
beta=zeros(1,numSeries);

for nii=1:numSeries
		A(nii)= 1/pi*sum(fx.*cos((nii-1)*omega*x))*dx;
		beta(nii) = sqrt(sq(n*wavenumber)-sq((nii-1)*omega));
end;


if FigNumber==3

    figure;[AX,H1,H2] = plotyy((0:numSeries-1)*omega/wavenumber,...
        (abs(A/2*pi*2)).^2/max((abs(A/2*pi*2)).^2),...
        (0:numSeries-1)*omega/wavenumber,real(beta)/wavenumber);
    set(get(AX(1),'Ylabel'),'String','P(k_x)'); 
    set(get(AX(2),'Ylabel'),'String','Re(n_{eff})');
    set(get(AX(1),'Xlabel'),'String','k_x/k_0');
    set(H1,'LineWidth',2);
    set(H2,'LineStyle','--','LineWidth',2,'Color','r');
    ylim(AX(2),[0 2]);set(AX(2),'ytickMode','auto')
else



  FONT_SIZE=20;
  format long;


  LightSpeed = 2.99e8;
  omega = wavenumber*LightSpeed;
  omegax=2*pi/2/XLength;
  XNum=100;
  ZNum=100;
  XLength=XLength/50;
  DeltaX = XLength/XNum;
  x=(-XNum:XNum)*DeltaX;
  ZLength=10*lambda;


  DeltaZ = ZLength/ZNum;
  Matrix_XPos = ones(ZNum,1)*x/lambda;
  Matrix_ZPos = (1:ZNum).'*DeltaZ*ones(1,XNum*2+1)/lambda;


  ZLengthNeg = lambda;
  ZNumNeg=ZLengthNeg/DeltaZ;
  Matrix_XNeg = ones(ZNumNeg+1,1)*x/lambda;
  Matrix_ZNeg = (-ZNumNeg:0)'*DeltaZ*ones(1,XNum*2+1)/lambda;


  if(FigNumber==5)
    ZLength=100*lambda;
    ZNum=ZNum/2;
    DeltaZ = ZLength/ZNum;
    z=linspace(0,ZNum,ZNum+1)*DeltaZ;
    y = zeros(length(z),1);
	Vector_Z = linspace(0,ZNum,ZNum+1)'*DeltaZ;

    for nii=1:numSeries
      y=y+A(nii)*omegax*exp(i*beta(nii)*Vector_Z);
    end; 
     
    y=sq(abs(y));
    x=0;
    figure; semilogy(z/lambda,y,'o');
    hold on;
    z=z(2:end);
    r=sqrt(sq(x)+sq(z));
    phy0=n*2*pi/lambda*r;
    phyPP=-z*(lambda/2/pi/n);
    Exz=A(1)./2.*exp(i*phy0).*sqrt(-2./phyPP).*((1-i)/sqrt(2)*sqrt(pi));
    plot(z/lambda,abs(Exz).*abs(Exz),'r','LineWidth',2);
    xlabel('z/\lambda');ylabel('I_{norm}');
  else


  tNum=10;
  tTotal =2*pi/omega;
  tArray=tTotal/tNum:tTotal/tNum:tTotal;
    for tii=1:tNum
      Vector_T = tArray(tii);
      MatrixPos=zeros(ZNum,XNum*2+1);
      Vector_Z = linspace(1,ZNum,ZNum)*DeltaZ;
      fprintf('Generating figure %d/10\n',tii);
      for nii=1:numSeries
        for ii=1:ZNum
			MatrixPos(ii,:)=MatrixPos(ii,:)+A(nii)*cos((nii-1)*omegax*x)...
                *omegax*exp(i*(beta(nii)*Vector_Z(ii)-omega*Vector_T));
        end;
      end;
 

 
      MatrixNeg =zeros(ZNumNeg+1,XNum*2+1);
   	  Vector_ZNeg = -1* linspace(ZNumNeg,0,ZNumNeg+1)*DeltaZ;

      for nii=1:numSeries
        for ii=1:ZNumNeg+1
			MatrixNeg(ii,:)=MatrixNeg(ii,:)+A(nii)*cos((nii-1)*omegax*x)*omegax...
                *exp(i*(wavenumber*Vector_ZNeg(ii)-omega*Vector_T));
        end;
      end;

  


      Matrix_Z = [Matrix_ZNeg;Matrix_ZPos];
      Matrix_X = [Matrix_XNeg;Matrix_XPos];
      Matrix =   [MatrixNeg;MatrixPos];
      Matrix = Matrix / max(max(abs(Matrix)));

      figure(1);hold off;

	  [ct,h,cf] = contourf(Matrix_X,Matrix_Z,real(Matrix),linspace(-1,1,20));

      for k = 1:length(h)	set(h(k),'linestyle','none'); end;
      set(gca,'xtick',[-10 -5 0 5 10],'XTickLabel',[]);
      set(gca,'ytick',[-1 0 1 2 3 4 5 6 7 8 9 10],'YTickLabel',[]);

      set(gca,'FontSize',16,'FontName','Times New Roman','TickDir','out');
      tls = [0.03 0.25];set(gca,'TickLength',tls);
      hold on;
      plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[0 0],'k:','LineWidth',2);
      plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[min(Matrix_Z(:,1)) min(Matrix_Z(:,1))],'k');
      plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[max(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
      plot([min(Matrix_X(1,:)) min(Matrix_X(1,:))],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
      plot([max(Matrix_X(1,:)) max(Matrix_X(1,:))],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
	  [cmin,cmax]=caxis;
	  caxis([-1,1]);
	  hold on;
      colorbar('YTickLabel',' ');

      htxt = text(0,0,'1');
	  set(htxt,'Position',[12.5 10],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	  htxt = text(0,0,'-1');
	  set(htxt,'Position',[12.5 -0.9],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	  htxt = text(0,0,'{\it x}/\lambda');
	  set(htxt,'Position',[-1.5 -1.9],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.6);
	  htxt = text(0,0,'{\it z}/\lambda');
	  set(htxt,'Rotation',90,'Position',[-12 4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.6);
	  htxt = text(0,0,'-10');
	  set(htxt,'Position',[-11 -2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	  htxt = text(0,0,'10');
	  set(htxt,'Position',[9.5 -2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	  htxt = text(0,0,'10');
	  set(htxt,'Position',[-12.2 10],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	  htxt = text(0,0,'0');
	  set(htxt,'Position',[-11.7 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	  htxt = text(0,0,'-1');
	  set(htxt,'Position',[-12.2 -1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);


      hold off;
      m=100+tii;
      print ('-dpsc2',strcat('movie/Fig4_',int2str(m),'.ps'));
      %print ('-dpng',strcat('mv',int2str(k),'.png'));
      % mogrify -format gif *ps

    end;
  end;
end;