%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function WTypePropagation(A,Ce,beta,n1,n2,a,b,numSeries,...
        wavenumber,plotsign)
sq=inline('x.*x','x');


FONT_SIZE=20;
format long;

lambda = 2*pi/wavenumber;
XLength = 30*a;
deltaX=a/10;
XNum = round(XLength/deltaX);
LightSpeed = 2.9e8;
omega = wavenumber*LightSpeed;

ZNum=100;


x=linspace(-XNum,XNum,2*XNum+1)*deltaX;


gamma= sqrt(sq(n1*wavenumber)-beta.*beta);
omegawidth = gamma(2:end) - gamma(1:end-1);
omegawidth = [omegawidth omegawidth(end)];


ZLength=10*lambda;
DeltaZ = ZLength/ZNum;
Matrix_XPos = ones(ZNum,1)*linspace(-XLength,XLength,XNum*2+1)/lambda;
Matrix_ZPos = (linspace(DeltaZ,ZLength,ZNum)')*ones(1,XNum*2+1)/lambda;

ZLengthNeg = lambda;
ZNumNeg=ZLengthNeg/DeltaZ;
Matrix_XNeg = ones(ZNumNeg+1,1)*linspace(-XLength,XLength,XNum*2+1)/lambda;
Matrix_ZNeg = linspace(-ZLengthNeg,0,ZNumNeg+1)'*ones(1,XNum*2+1)/lambda;

tNum=10;
tTotal =2*pi/omega;
tArray=tTotal/tNum:tTotal/tNum:tTotal;


for tii=1:tNum
    
   
    Vector_T = tArray(tii) ;
    MatrixPos=zeros(ZNum,XNum*2+1);
    Vector_Z = linspace(1,ZNum,ZNum)*DeltaZ;


    fprintf('Generating figure %d/%d\n',tii,tNum);
 
  
    MatrixNeg =zeros(ZNumNeg+1,XNum*2+1);
    Vector_ZNeg = -1* linspace(ZNumNeg,0,ZNumNeg+1)*DeltaZ;

    for nii=1:numSeries
        tempnii=A(nii)*WTypePlotback(Ce(nii),n1,n2,a,b,XLength,deltaX,wavenumber,beta(nii))*...
				omegawidth(nii);
        for ii=1:ZNum
			MatrixPos(ii,:)=MatrixPos(ii,:)+tempnii*exp(i*(beta(nii)*Vector_Z(ii)-omega*Vector_T));
        end;
        for ii=1:ZNumNeg+1
            MatrixNeg(ii,:)=MatrixNeg(ii,:)+tempnii*exp(i*(wavenumber*Vector_ZNeg(ii)-omega*Vector_T));
        end;
    end;




    Matrix_Z = [Matrix_ZNeg;Matrix_ZPos];
    Matrix_X = [Matrix_XNeg;Matrix_XPos];
    Matrix =   [MatrixNeg;MatrixPos];

    Matrix= Matrix/max(max(abs(Matrix)));

    figure(3);hold off;

	[ct,h,cf] = contourf(Matrix_X,Matrix_Z,real(Matrix),linspace(-1,1,20));
    for k = 1:length(h)	set(h(k),'linestyle','none'); end;
    set(gca,'xtick',[-10 -5 0 5 10],'XTickLabel',[]);
    set(gca,'ytick',[-1 0 1 2 3 4 5 6 7 8 9 10],'YTickLabel',[]);

    set(gca,'FontSize',16,'FontName','Times New Roman','TickDir','out');
    tls = [0.03 0.25];set(gca,'TickLength',tls);

    hold on;
    plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[0 0],'k:','LineWidth',2);
    plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[min(Matrix_Z(:,1)) min(Matrix_Z(:,1))],'k');
    plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[max(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
    plot([-10 -10],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
    plot([10 10],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');

    plot([-a/lambda -a/lambda],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k-.','LineWidth',2);
    plot([a/lambda a/lambda],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k-.','LineWidth',2);
    plot([-b/lambda -b/lambda],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k--','LineWidth',2);
    plot([b/lambda b/lambda],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k--','LineWidth',2);
   
   
    [cmin,cmax]=caxis;
	caxis([-1,1]);
	hold on;
    axis([-10,10,-1,10]);

    box on;

    colorbar('YTickLabel',' ');
    htxt = text(0,0,'1');
	set(htxt,'Position',[12.5 10],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'-1');
	set(htxt,'Position',[12.5 -0.9],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'{\it x}/\lambda');
	set(htxt,'Position',[-1.5 -1.9],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.6);
	htxt = text(0,0,'{\it z}/\lambda');
	set(htxt,'Rotation',90,'Position',[-12 4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.6);
	htxt = text(0,0,'-10');
	set(htxt,'Position',[-11 -2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'10');
	set(htxt,'Position',[9.5 -2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'10');
	set(htxt,'Position',[-12.2 10],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'0');
	set(htxt,'Position',[-11.7 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'-1');
	set(htxt,'Position',[-12.2 -1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);



    m=100+tii;
    print ('-dpsc2',strcat('movie/Fig12_',int2str(m),'.ps'));

end;








