%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function Yeh59Mode(x)

sq=inline('x.*x','x');
load data/lambda.dat ;
load data/pitch.dat ;
load data/a.dat ;
load data/b.dat ;
load data/n1.dat;
load data/n2.dat;
load data/na.dat;
load data/t.dat;
load data/numlayer.dat;
load data/debugsign.dat

wavenumber = 2*pi/lambda;
beta = x;   

k1x=sqrt(sq(wavenumber*n1)-sq(beta));
k2x=sqrt(sq(wavenumber*n2)-sq(beta));
A=exp(-i*k1x*a).*(cos(k2x*b)-i/2*(k2x./k1x+k1x./k2x).*sin(k2x*b));
B=exp(i*k1x*a).*(-i/2*(k2x./k1x-k1x./k2x).*sin(k2x*b));
C=exp(-i*k1x*a).*(i/2*(k2x./k1x-k1x./k2x).*sin(k2x*b));
D=exp(i*k1x*a).*(cos(k2x*b)+i/2*(k2x./k1x+k1x./k2x).*sin(k2x*b));
K=1/pitch*acos(1/2*(A+D));
K = real(K)+i*abs(imag(K));

ka=sqrt(sq(wavenumber*na)-sq(beta));




a0=-B;
b0=-exp(-i*K*pitch)+A;
abii = [a0; b0];
Ki=imag(K);
N=40;



alpha=(a0+b0)/cos(ka*t/2);

x=[];E=[];
xa=0:t/100:t/2;
Ea=alpha*cos(ka*xa);
x=[x xa];E=[E Ea];Index=na*ones(size(x));


abTocd0 = [exp(-i*k2x*pitch) exp(i*k2x*pitch); k2x/k1x*exp(-i*k2x*pitch) -k2x/k1x*exp(i*k2x*pitch)];
abTocd = inv(abTocd0)*[1 1; 1 -1];

abToab = inv([A B;C D]);
for ii=1:N
    cdii=abTocd*abii;
    abii=abToab*abii;

    xiicd=(ii-1)*pitch:pitch/100:(ii-1)*pitch+pitch/2;
    Eiicd=cdii(1)*exp(i*k2x*(xiicd-ii*pitch))+cdii(2)*exp(-i*k2x*(xiicd-ii*pitch));
    xiiab=(ii-1)*pitch+pitch/2:pitch/100:(ii-1)*pitch+pitch;
    Eiiab=abii(1)*exp(i*k1x*(xiiab-ii*pitch))+abii(2)*exp(-i*k1x*(xiiab-ii*pitch));

    x=[x xiicd+t/2];    E=[E Eiicd]; Index=[Index n2*ones(size(Eiicd))];    
    x=[x xiiab+t/2];    E=[E Eiiab]; Index=[Index n1*ones(size(Eiiab))];    
end;

x = [-1*fliplr(x(2:end)) x];
E = -1*[fliplr(E(2:end)) E];
Index = [1*fliplr(Index(2:end)) Index];



    figure;
    [AX,H1,H2] = plotyy(x/lambda, (real(E)/max(real(E))),...
        x/lambda, Index);
    set(get(AX(1),'Ylabel'),'String','Re[E(x)]'); 
    set(get(AX(2),'Ylabel'),'String','n(x)');
    set(get(AX(1),'Xlabel'),'String','x/\lambda');
    set(H2,'Color','b');
    set(H1,'LineStyle','--','LineWidth',2,'Color','r');
    xlim(AX(1),[-5 5]);
    xlim(AX(2),[-5 5]);
    ylim(AX(1),[-0.2 1]);set(AX(1),'ytickMode','auto');
    ylim(AX(2),[0 3.5]);set(AX(2),'ytickMode','auto');


